#
# spec file for package tdb
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python_sitearch:  %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%{!?py3_soflags:  %global py3_soflags cpython-%{python3_version_nodots}m}
Name:           tdb
VCS: https://src.suse.de/SLFO-pool/tdb?trackingbranch=main#189afd0a673dd476c2093832309206fefe85435bf684fc3c47e0a9bc146a29a2
Version:        1.4.13
Release:        160000.2.2
Summary:        Samba Trivial Database
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://tdb.samba.org/
Source:         https://download.samba.org/pub/tdb/tdb-%{version}.tar.gz
Source1:        https://download.samba.org/pub/tdb/tdb-%{version}.tar.asc
Source2:        tdb.keyring
Source4:        baselibs.conf
Patch0:         build_pie.patch
BuildRequires:  autoconf
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  doxygen
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  python3-devel

%description
TDB is a Trivial Database. In concept, it is very much like GDBM, and BSD's DB,
except that it allows multiple simultaneous writers and uses locking
internally to keep writers from trampling on each other.

%package -n libtdb1
Summary:        Samba Trivial Database
Group:          System/Libraries

%description -n libtdb1
TDB is a Trivial Database. In concept, it is very much like GDBM, and BSD's DB,
except that it allows multiple simultaneous writers and uses locking
internally to keep writers from trampling on each other.

This package contains the tdb1 library.

%package -n libtdb-devel
Summary:        Libraries and Header Files to Develop Programs with tdb1 Support
Group:          Development/Libraries/C and C++
Requires:       libtdb1 = %{version}
Requires:       pkgconfig

%description -n libtdb-devel
TDB is a Trivial Database. In concept, it is very much like GDBM, and BSD's DB,
except that it allows multiple simultaneous writers and uses locking
internally to keep writers from trampling on each other.

This package contains libraries and header files need for development.

%package -n tdb-tools
Summary:        Tools to manipulate tdb files
Group:          Development/Libraries/C and C++

%description -n tdb-tools
TDB is a Trivial Database. In concept, it is very much like GDBM, and BSD's DB,
except that it allows multiple simultaneous writers and uses locking
internally to keep writers from trampling on each other.

This package contains tools to manage Tdb files.

%package -n python3-tdb
Summary:        Python3 bindings for the Tdb library
Group:          Development/Libraries/Python
Requires:       libtdb1 = %{version}
Obsoletes:      python-tdb

%description -n python3-tdb
This package contains the Python3 bindings for the Tdb library.

%prep
%setup -q -n tdb-%{version}
%autopatch -p1

%build
export CFLAGS="%{optflags} -D_GNU_SOURCE -D_LARGEFILE64_SOURCE -DIDMAP_RID_SUPPORT_TRUSTED_DOMAINS"
./configure --prefix=%{_prefix} \
	--libdir=%{_libdir} \
	--disable-rpath \
	--disable-rpath-install \
	--disable-silent-rules \
	--bundled-libraries=NONE

%make_build all
doxygen doxy.config

%check
%if 0%{!?qemu_user_space_build:1}
%make_build test
%endif

%install
%make_install
# Install API documentation
mkdir -p %{buildroot}/%{_mandir}/man3/
cp -a docs/man/man3/tdb.3 %{buildroot}/%{_mandir}/man3/

%post -n libtdb1 -p /sbin/ldconfig
%postun -n libtdb1 -p /sbin/ldconfig

%files -n libtdb1
%{_libdir}/libtdb.so.*

%files -n libtdb-devel
%{_includedir}/tdb.h
%{_libdir}/libtdb.so
%{_libdir}/pkgconfig/tdb.pc
%{_mandir}/man3/tdb.3%{?ext_man}

%files -n tdb-tools
%{_bindir}/tdbbackup
%{_bindir}/tdbdump
%{_bindir}/tdbrestore
%{_bindir}/tdbtool
%{_mandir}/man8/tdbbackup.8%{?ext_man}
%{_mandir}/man8/tdbdump.8%{?ext_man}
%{_mandir}/man8/tdbrestore.8%{?ext_man}
%{_mandir}/man8/tdbtool.8%{?ext_man}

%files -n python3-tdb
%{python3_sitearch}/tdb.%{py3_soflags}.so
%{python3_sitearch}/_tdb_text.py
%if 0%{?centos_version} > 599 || 0%{?fedora_version} > 11 || 0%{?rhel_version} > 599
%{python3_sitearch}/__pycache__/_tdb_text.cpython-*.py[co]
%endif

%changelog
* Wed Mar 12 2025 scabrero@suse.de
- Update to 1.4.13
  * Add LGPLv3 LICENSE file
* Tue Sep 10 2024 nopower@suse.com
- Update to 1.4.12
  * Regression fix for ABI problem
    TDB_1_4_11 vs. TDB_1.4.11
- Update to 1.4.11
  * Add tdbdump -x option to output all data as hex values
  * Add missing overflow check for num_values in pytdb.c
  * Remove Py2 related tests
  * Update times in tdb_transaction_commit per fd, not per name
  * Fix compilation with TDB_TRACE=1
  * Allow tracing of internal tdb
* Thu May 16 2024 scabrero@suse.de
- Update to 1.4.10
  * build with Python 3.12 (bso#15513)
  * documentation fixes
  * minor build fixes
* Tue Sep 26 2023 nopower@suse.com
-  Update to 1.4.9
  * Remove remaining, but broken python2 support
  * Spelling fixes
  * python: Safely clear structure members
* Fri Mar 17 2023 scabrero@suse.de
- Update to 1.4.8:
  * Support python 3.12
* Sat Sep 17 2022 dmueller@suse.com
- update to 1.4.7:
  * configure/Makefile: export PYTHONHASHSEED=1 in all 'configure/Makefile' scripts
  * lib:tdb: Reformat shell scripts
- spec file cleanups
* Wed Mar 16 2022 jcnengel@gmail.com
- Update to 1.4.6
  + Drop obsolete patch 0001-tdb-Fix-invalid-syntax-in-tdb.h.patch
  + Fix Python docstrings
  + Use atomic operations for tdb_[increment|get]_seqnum
  + Raw performance torture to beat tdb_increment_seqnum
* Fri Sep 17 2021 scabrero@suse.de
- Update to version 1.4.4
  + Fix a memory leak on error
  + python: remove all 'from __future__ import print_function'
  + Fix CID 1471761 String not null terminated
  + Use hex_byte() in parse_hex()
  + Use hex_byte() in read_data()
  + fix studio compiler build
  + Fix some signed/unsigned comparisons
  + also use __has_attribute macro to check for attribute support
  + Fix clang 9 missing-field-initializer warnings
  + pytdb tests: add test for storev()
  + pytdb: add python binding for storev()
  + tdbtorture: Use ARRAY_DEL_ELEMENT()
  + py3: Remove #define PyInt_FromLong PyLong_FromLong
  + py3: Remove #define PyInt_AsLong PyLong_AsLong
  + py3: Remove #define PyInt_Check PyLong_Check
  + tdb: Align integer types
- Drop obsolete patch ignore-tdb1-run-transaction-expand.diff
- Fix header file using undefined function visibility macro;
  Add patch 0001-tdb-Fix-invalid-syntax-in-tdb.h.patch; (bso#14762);
* Fri Mar  6 2020 nopower@suse.com
- Update to version 1.4.3
  + Upgrade waf to version 2.0.18 to fix a cross-compilation issue;
    (bso#13846).
  + lib/tdb/docs/tracing.txt: typo fixes
* Thu Oct  3 2019 jmcdonough@suse.com
- Update to version 1.4.2
  + Build fixes
  + Improve the performance by inlining the tdb_oob() checks
  + Do not propogate any errors from tdb_repack() to
    tdb_transaction_commit();  (bso#13952)
  + Remove Python 2.x support except to build just the bare C library
  + Remove --extra-python (a build time mode to produce Python2 and Python3
    bindings at the same time)
  + New minor version to allow Samba 4.10 to release a tdb if
    required from that branch
* Tue Mar  5 2019 dmulder@suse.com
- Update to 1.3.18
  + Fix build problems with older python versions.
  + C99 build fixes.
  + Fix standalone build of tdb.
* Wed Jan 23 2019 dmulder@suse.com
- Update to 1.3.17
* Tue Sep 25 2018 scabrero@suse.de
- Update license to LGPL-3.0
* Wed Aug  8 2018 dmulder@suse.com
- Update to 1.3.16.
  + Fix build on AIX
  + Python3 compatibility fixes
  + Use tdb_wipe_all in "erase" command
  + Harden allocating the tdb recovery area
  + Make sure the hash size fits
  + Harden tdb_check_used_record against overflow
  + Harden tdb_rec_read
  + Handle TDB_NEXT_LOCK_ERR in tdb_traverse_internal
  + Fix build warnings
* Fri Apr 27 2018 david.mulder@suse.com
- Remove the conflicts between python3-tdb and python-tdb. These
  packages don't actually conflict, and need to be installed
  together in order to build samba with python3.
* Mon Oct  2 2017 jengelh@inai.de
- Remove %%if guards for blocks that do not affect the build result.
  Fix RPM groups and summaries. Ensure neutrality of descriptions.
  Drop very old SUSE support. Replace old RPM macros by new
  constructs. Remove some useless ldconfig calls.
* Mon Sep 25 2017 scabrero@suse.com
- Update to 1.3.15.
  + Add protection against EINTR.
  + Truncate the file after expand failure, ENOSPC
  + Use posix_fallocate() to expand the file
  + Fix GCC compiler warnings
* Wed Jul  5 2017 scabrero@suse.com
- Update to version 1.3.14.
  + allow tdb_traverse_read before tdb_transaction[_prepare]_commit()
  + Improve documentation for tdb_transaction_start()
  + Add new function tdb_transaction_active()
* Fri Jun 30 2017 scabrero@suse.com
- Update to version 1.3.13.
  + documentation for the tdbbackup -n option
  + correctly upgrade F_RDLCK to F_WRLCK locks
  + tdbtool: Add "storehex" command
  + fix robust mutex detection in threaded applications
    (bug #12593)
  + improve debugging of transaction lock failures
* Tue Jan 24 2017 ddiss@suse.com
- Update to version 1.3.12; (bsc#1032915).
  + Fix mutexes on FreeBSD
  + Only mmap the mutex area if not already mmap'ed
  + NULL out tdb->mutexes in tdb_mutex_munmap
* Wed Sep 14 2016 jmcdonough@suse.com
- Update to version 1.3.11.
  + performance improvements
  + make pthread mutex code more portable
  + avoid a race condition when checking for robust mutexes
    (bso#11808)
  + Remove use of strcpy in tdb test.
  + eliminate deprecation warnings in python tests
  + Only set public headers field when installing as a public library.
* Sun Feb 21 2016 lmuelle@suse.com
- Add conflict between python-tdb and python3-tdb.
* Sun Feb 21 2016 lmuelle@suse.com
- Avoid a file collision for non SUSE build targets; (bsc#966174).
* Wed Nov 11 2015 lmuelle@suse.com
- Update to version 1.3.8; (bsc#954658).
  + Fix broken build with --disable-python
  + Minor build fixes
* Fri Oct 30 2015 lmuelle@suse.com
- Add doxygen at build time to add the development documentation.
- Disable rpath-install and silent-rules while configure.
* Sun Oct 25 2015 lmuelle@suse.com
- Add python3-tdb; (bsc#951911).
* Mon Sep  7 2015 lmuelle@suse.com
- Update the Samba Library Distribution Key file 'tdb.keyring'; (bso#945116).
* Wed Jul 22 2015 lmuelle@suse.com
- Update to version 1.3.7.
  + first fix deadlock in the interaction between fcntl and mutex locking;
    (bso#11381)
  + improved python3 bindings
* Sat Jun 27 2015 lmuelle@suse.com
- Update to version 1.3.6.
  + Fix runtime detection for robust mutexes in the standalone build;
    (bso#11326).
  + Possible fix for the build with robust mutexes on solaris 11; (bso#11319).
- Update to version 1.3.5.
  + ABI change: tdb_chainlock_read_nonblock() has been added, a nonblock
    variant of tdb_chainlock_read()
  + Do not build test binaries if it's not a standalone build
  + Fix CID 1034842 Resource leak
  + Fix CID 1034841 Resource leak
  + don't let tdb_wrap_open() segfault with name==NULL
* Tue Jan 13 2015 lmuelle@suse.com
- Update to version 1.3.4.
  + toos: allow transactions with TDB_MUTEX_LOCKING
  + test: add tdb1-run-mutex-transaction1 test
  + allow transactions on on tdb's with TDB_MUTEX_LOCKING
* Sun Dec 21 2014 lmuelle@suse.com
- Update to version 1.3.3.
  + test: TDB_CLEAR_IF_FIRST | TDB_MUTEX_LOCKING, O_RDONLY is a valid
    combination
- Update to version 1.3.2.
  + allow tdb_open_ex() with O_RDONLY of TDB_FEATURE_FLAG_MUTEX tdbs.
  + Fix a comment
  + Fix tdb_runtime_check_for_robust_mutexes()
  + Improve wording in a comment
  + tdb.h needs bool type; obsoletes include_stdbool_bso10625.patch
  + tdb_wrap: Make mutexes easier to use
  + tdb_wrap: Only pull in samba-debug
  + tdb_wrap: Standalone compile without includes.h
  + tdb_wrap: tdb_wrap.h doesn't need struct loadparm_context
* Thu Nov  6 2014 lmuelle@suse.com
- Use the upstream tar ball, as signature verification is now able to handle
  compressed archives.
* Tue Oct 28 2014 lmuelle@suse.com
- Remove dependency on gpg-offline as signature checking is implemented in the
  source validator.
* Tue Sep 23 2014 lmuelle@suse.com
- Update to version 1.3.1.
  + tools: fix a compiler warning
  + defragment the freelist in tdb_allocate_from_freelist()
  + add "freelist_size" sub-command to tdbtool
  + use tdb_freelist_merge_adjacent in tdb_freelist_size()
  + add tdb_freelist_merge_adjacent()
  + add utility function check_merge_ptr_with_left_record()
  + simplify tdb_free() using check_merge_with_left_record()
  + add utility function check_merge_with_left_record()
  + improve comments for tdb_free().
  + factor merge_with_left_record() out of tdb_free()
  + fix debug message in tdb_free()
  + reduce indentation in tdb_free() for merging left
  + increase readability of read_record_on_left()
  + factor read_record_on_left() out of tdb_free()
  + build: improve detection of srcdir.
* Fri May 23 2014 lmuelle@suse.com
- Update to version 1.3.0.
  + add TDB_MUTEX_LOCKING support
  + consolidate tdb allocation code - re-use dead records at hash top.
  + don't alter errno on success of tdb_open_ex()
  + introduce tdb->hdr_ofs
  + introduce TDB_SUPPORTED_FEATURE_FLAGS
  + return ENOSYS if the tdb was created with spinlocks.
  + use asprintf() to simplify tdb_summary()
  + test: add a "skip()" macro.
    add marklock deadlock test
    add mutex related tests
    add PING command to external-agent.c
    add shutdown_agent() helper function
    add UNMAP command to external-agent.c
    always call fflush() after [f]printf() in tap-interface.h
    avoid const warnings by using 'discard_const_p(uint8_t,' instead of
  '(void *)'
    correctly use stderr, not stdout, in fail()
    remove "\n" in diag() arguments
  + tools: add -l option to tdbbackup
    add -l option to tdbtool
    add -m option to tdbtorture
    Allow tdbtool to r/o open mutexed tdbs
    avoid const warnings in tdbdump.c
    explicitly use TDB_NOLOCK in tdbdump
  + tdb_wrap: Remove tdb_wrap_open_ again
  + wscript: maintain a global list of unit tests
- Include stdbool.h in tdb.h; (bso#10625).
  + include_stdbool_bso10625.patch
* Fri May 23 2014 lmuelle@suse.com
- Don't require pkg-config from the libtdb package.
* Thu Mar 20 2014 lmuelle@suse.com
- Update to version 1.2.13.
  + Reduce freelist contention
  + Make "tdb_purge_dead" internally public
  + Make "tdb_find_dead" internally public
  + Add "last_ptr" to tdb_find_dead
  + Move adding tailer space to tdb_find_dead
  + Do a best fit search for dead records
  + Don't purge records to a blocked freelist
  + Fix a tdb corruption
  + always open internal databases with incompatible hash.
  + in tdb_delete_hash, make lock/unlock bracket more obvious
  + simplify tdb_delete_hash() a bit
  + tdbtool: dump record magic with fixed number of 8 hex digits
  + tdbtool: dump record hash with fixed number of 8 hex digits
  + Avoid reallocs for lockrecs
  + Fix some typos in comments.
  + Fix CID 1034959 Uninitialized scalar variable
  + Fix CID 1034960 Uninitialized scalar variable
  + Fix typos.
* Fri Dec  6 2013 lmuelle@suse.com
- Verify source tar ball gpg signature.
* Wed Dec  4 2013 mls@suse.de
- Adapt specfile to ppc64le.
* Thu Aug 29 2013 lmuelle@suse.com
- PreReq /sbin/ldconfig from python-tdb.
* Thu Aug 29 2013 lmuelle@suse.com
- Add python-tdb to baselibs.conf.
* Mon Jul 22 2013 lmuelle@suse.com
- Don't package tdb tools man pages for pre-11.0 systems as they're not built
  due to a missing docbook stylesheet.
* Tue Jun  4 2013 lmuelle@suse.com
- Update to version 1.2.12.
  + internal code cleanups
  + crash fix for pytdb
  + fix for 4GB overflow detection
* Mon Jan  7 2013 dvaleev@suse.com
- Refresh ignore-tdb1-run-transaction-expand.diff patch.
* Sun Dec  2 2012 lmuelle@suse.com
- Update to version 1.2.11.
  + Make tdb robust against improper CLEAR_IF_FIRST restart
  + Make robust against shrinking tdbs
  + add -e option to tdbdump (and docment it).
  + tdbdump should log errors, and fail in that case.
  + add tdb_rescue()
  + Fix a typo
  + return unpack error on strdup failure
  + finish weaning off err.h.
  + don't use err.h in tests.
  + make TDB_NOSYNC merely disable sync.
  + remove unused debug_fprintf() macro that breaks the build
  + tests: fix use of a non-existent word (existant)
* Sat Jul  7 2012 dvaleev@suse.com
- Ignore tdb run transaction expand check on ppc as well; (bnc#769268).
* Thu Jun 28 2012 lmuelle@suse.com
- Ignore tdb run transaction expand check on ppc64; (bnc#769268).
* Thu Jun 21 2012 adrian@suse.de
- disable test suite on qemu emulated builds
* Wed Jun 13 2012 ddiss@suse.com
- Build and link binaries with PIE flags.
* Tue Jun  5 2012 lmuelle@suse.com
- Remove superfluous tdb-tools rpmlintrc; (bnc#765476).
* Sun Jun  3 2012 lmuelle@suse.com
- Define library name and use it instead of libtdb1.
* Sat Jun  2 2012 lmuelle@suse.com
- Add tdb tar ball gpg signature as source.
* Sat Jun  2 2012 lmuelle@suse.com
- Rename package to tdb and add an independent libtdb1 subpackage.
- Rename rpmlintrc file from libtdb1 to tdb-tools.
- Remove bogus requires to itself from libtdb1 package.
* Thu May 31 2012 lmuelle@suse.com
- BuildRequire pkg-config for post-10.2 systems and else pkgconfig.
* Thu May 31 2012 lmuelle@suse.com
- Rename libtdb1-devel to libtdb-devel.
* Wed May 30 2012 lmuelle@suse.com
- Define python_sitearch if undefined.
* Wed May 30 2012 lmuelle@suse.com
- Remove superfluous AutoReqProv on line.
* Wed May 16 2012 lmuelle@suse.com
- Require pkg-config from the devel package.
* Wed May 16 2012 lmuelle@suse.com
- Move python file to python-tdb subpackage.
- Build and add tdbbackup, tdbdump, tdbrestore, and tdbtool man pages.
* Wed May 16 2012 lmuelle@suse.com
- Cleanup BuildRequires.
- Polish package descriptions.
- Add rpmlintrc file to set badness for non PIE code to 0.
* Wed Sep  7 2011 lars@samba.org
- Initial independent libtdb1 package.
